.Dd Sep 13, 2008
.Dt scgid 8
.Sh NAME
.Nm scgid
.Nd Do-Nothing SCGI Server
.Sh SYNOPSIS
.Nm scgid -r Ao root dir Ac Oo -n Ao min-servers Ac -m Ao max-servers Ac -i Ao interface Ac -p Ao port Ac -u Ao user Ac -g Ao group Ac -x Oc
.Sh DESCRIPTION
Scgid is a skeletal Simple Common Gateway Interface server.  It sends the
SCGI enivronment data back to the client, and nothing more.  It was written
to serve as a companion test server for the drood web server.  Scgid
accepts both IPv4 and IPv6 connections.
.Pp
Starting-up and shutting-down processes for traditional CGI programs
becomes a performance bottleneck on busy servers.  The SCGI protocol
specifies a simple means by which a web server can forward a request to a
persistent application to generate the response.  It is well-suited for use
by language-processors.  The programmer writes his or her web apps in his
or her favorite dynamic language, and the web server forwards requests for
those resources to the SCGI server.  The language processor, acting as SCGI
server, maintains a pool of persistent processes to service incoming
requests.  Process start-up and shut-down, and language processor
initialization costs are eliminated for each request, resulting in
significantly better performance over traditional CGI.  To supply multiple
applications to clients, multiple SCGI servers must be run, each listening
on a different port or host.
.Pp
Scgid writes its pid into /var/run/scgid.pid, if it can (ie., it is started
as root), and may be stopped with a SIGTERM.  A rc.d script is provided and
installed in /usr/local/etc/rc.d/.  Add the following lines to /etc/rc.conf
to start scgid on system boot-up.  Replace the items in brackets with
values appropriate for your system, and/or add or remove options as suits
your system.  The available options are described in full at the end of
this manual page.
.Bd -literal -offset left
scgid_enable="YES"
scgid_flags="-r <root dir> -u <user> -g <group>"
.Ed
.Pp
Once your /etc/rc.conf is configured you may start, stop, or restart scgid,
or determine if it is running with the following commands:  
.Bd -literal -offset left
/usr/local/etc/rc.d/scgid start
/usr/local/etc/rc.d/scgid stop
/usr/local/etc/rc.d/scgid restart
/usr/local/etc/rc.d/scgid status
.Ed
.Pp
If you do not want scgid started on system start, then set
.Bd -literal -offset left
scgid_enable="NO"
.Ed
.Pp
and use the following commands:
.Bd -literal -offset left
/usr/local/etc/rc.d/scgid forcestart
/usr/local/etc/rc.d/scgid forcestop
/usr/local/etc/rc.d/scgid forcerestart
/usr/local/etc/rc.d/scgid forcestatus
.Ed
.Pp
If the server encounters an error reading or writing data to or from
a client, or runs out of memory, the particular connection which generated
the error will be dropped.  Most errors will be logged via syslog(3), and
may be found in /var/log/messages.
.Pp
The following arguments are recognized.  The -r option is mandatory.  The
rest are optional.
.Bl -tag -width "-i"
.It -r
The -r option specifies the server root directory.  Scgid will chroot(2) to
this directory.  Setting the value of this option to the web server root 
directory will usually mean the paths in SCRIPT_NAME can used as is,
because they are usually specified as absolute paths, but as if the web
server root was the filesystem root.
.It -p
The -p option specifies the port to listen on.  This defaults to 4000 if
not specified.
.It -i
By default, scgid accepts connections on all interfaces it can find capable
of IPv4 or IPv6.  The -i option, when present, overrides this behavior, by
limiting scgid to accepting connections from a specified interface only.
The option accepts the IP address of the desired interface as an argument.
The address must be expressed in the presentation format for either IPv4 or
IPv6.  The intent of this option is to allow the administrator to prevent
the outside world from accessing a server during testing by making scgid
bind only to one interface (eg., the loopback address).
.It -m
.It -n
Scgid uses a multi-process model, with one master process forking or
killing slave processes in response to client activity.  Only the slave
processes service client requests.  The -n options specifies the number of
idle slaves the master will attempt to keep ready at all times.  The -m
option specifies the maximum number of slaves which may be running at any
time.  The value specified must be equal to or greater than the value
specified for -n.  The default value for -n is 3 and the default value for
-m is 25.
.It -u
.It -g
Scgid tries to setuid to user "nobody" and setgid to group "nobody" after
binding the listening socket.  If it is unsuccessful, the server will exit.
To be able to change users, scgid must be started as root.  The -u and the
-g options may be used to specify a different user and group.
.It -x
The -x option, if present, prevents scgid from becoming a daemon.  It will
then run in the foreground of the terminal where it was started, and may be
stopped with signals (ie., Control-C).  The values of -m and -n will be
ignored, and only one iterative server will be run.  The server also will
not write its pid to /var/run/scgid.pid when the -x option is used.
.El
.Sh AUTHORS
.An James Bailie Aq jimmy@mammothcheese.ca
.br
http://www.mammothcheese.ca
